pub fn run_search_with_options(
query: &str,
target_path: &str,
opts: &SearchOptions,
)Expand description
Run search with explicit options and print top shell extraction commands.
pub fn run_search_with_options(
query: &str,
target_path: &str,
opts: &SearchOptions,
)Run search with explicit options and print top shell extraction commands.